Clojure only.

scicloj.ml.smile.discrete-nb


bow->SparseArrayclj

(bow->SparseArray ds bow-col indices-col options)

Converts a bag-of-word column bow-col to sparse indices column indices-col, as needed by the discrete naive bayes model. vocab size is the size of vocabluary used, sorted by token frequency

Converts a bag-of-word column `bow-col` to sparse indices column `indices-col`,
as needed by the discrete naive bayes model. `vocab size` is the size of vocabluary used, sorted by token frequency 
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries